@@ -33,6 +33,7 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesFanResponse,
     ListEntitiesLightResponse,
     ListEntitiesLockResponse,
+    ListEntitiesMediaPlayerResponse,
     ListEntitiesNumberResponse,
     ListEntitiesRequest,
     ListEntitiesSelectResponse,
@@ -43,6 +44,8 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesTextSensorResponse,
     LockCommandRequest,
     LockStateResponse,
+    MediaPlayerCommandRequest,
+    MediaPlayerStateResponse,
     NumberCommandRequest,
     NumberStateResponse,
     PingRequest,
@@ -183,4 +186,7 @@ MESSAGE_TYPE_TO_PROTO = {
     60: LockCommandRequest,
     61: ListEntitiesButtonResponse,
     62: ButtonCommandRequest,
+    63: ListEntitiesMediaPlayerResponse,
+    64: MediaPlayerStateResponse,
+    65: MediaPlayerCommandRequest,
 }
